Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(10)

Unified Diff: milo/appengine/logdog/logDogBuild.go

Issue 2250263005: Milo: Prefetch logs that are failures (Closed) Base URL: https://chromium.googlesource.com/external/github.com/luci/luci-go@master
Patch Set: URL fix Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: milo/appengine/logdog/logDogBuild.go
diff --git a/milo/appengine/logdog/logDogBuild.go b/milo/appengine/logdog/logDogBuild.go
index a1804e16ae01874562f5efca193bf88e0c3e0368..eb43e331db01b792728a9e69bda6a0af01b758f1 100644
--- a/milo/appengine/logdog/logDogBuild.go
+++ b/milo/appengine/logdog/logDogBuild.go
@@ -77,11 +77,14 @@ func miloBuildStep(ub URLBuilder, anno *miloProto.Step, buildCompletedTime, now
comp.Status = resp.InfraFailure
}
- // Hide the unimportant steps.
- if comp.Status == resp.Success {
+ // Hide the unimportant steps, highlight the interesting ones.
+ switch comp.Status {
+ case resp.Success:
if _, ok := builtIn[anno.Name]; ok {
comp.Verbosity = resp.Hidden
}
+ case resp.InfraFailure, resp.Failure:
+ comp.Verbosity = resp.Interesting
}
// Main link is a link to the stdout.
« no previous file with comments | « milo/appengine/frontend/templates/buildbot/pages/build.html ('k') | milo/appengine/swarming/expectations/build-canceled.json » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698